//
//  View.swift
//  Hello
//
//  Created by Mark Meretzky on 11/6/14.
//  Copyright (c) 2014 Mark Meretzky. All rights reserved.
//

import UIKit

class View: UIView {
	let label: UILabel = UILabel();
	
	required init(coder aDecoder: NSCoder) {
		super.init(coder: aDecoder);
		backgroundColor = UIColor.blueColor();

		//Initialize the properties of the label that do not depend on the
		//size of this View.
		label.backgroundColor = UIColor.clearColor();
		label.textColor = UIColor.whiteColor();
		addSubview(label);
	}

	//Called when the size of this View changes, for example when this View is created.
	//Set the properties of the label that depend on the size of this View.

	override func layoutSubviews() {
		label.font = UIFont.systemFontOfSize(bounds.size.height);
		let attributes: [NSObject: AnyObject] = [NSFontAttributeName: label.font];
		label.text = "GONE WITH THE WIND"; //ensure next statement can safely use text
		let textSize: CGSize = label.text!.sizeWithAttributes(attributes);

		//Label initially waiting in the wings, to the right of this View.
		label.frame = CGRectMake(
			bounds.origin.x + bounds.size.width,
			bounds.origin.y,
			textSize.width,
			bounds.size.height);
	}

	// Only override drawRect: if you perform custom drawing.
	// An empty implementation adversely affects performance during animation.
	override func drawRect(rect: CGRect) {
		// Drawing code
		UIView.animateWithDuration(24.5,
			delay: 23.75,
			options: UIViewAnimationOptions.CurveLinear,
			animations: {
				//Scroll the label far enough to the left
				//so that it's out of the View.
				self.label.center = CGPointMake(
					-self.label.bounds.size.width / 2,
					self.bounds.size.height / 2);
			},
			completion: nil);
	}

}
